bhapkar: Bhapkar coefficient of concordance between raters
Description
Calculates the Bhapkar coefficient of concordance for two raters.
Usage
bhapkar(ratings)
Value
A list with class "irrlist" containing the following components:
$method
a character string describing the method.
$subjects
the number of data objects.
$raters
the number of raters.
$irr.name
the name of the coefficient (Chisq).
$value
the value of the coefficient.
$stat.name
the name and df of the test statistic.
$statistic
the value of the test statistic.
$p.value
the probability of the test statistic.
Arguments
ratings
n*2 matrix or dataframe, n subjects 2 raters.
Author
Matthias Gamer
Details
Missing data are omitted in a listwise way.
The Bhapkar (1966) test is a more powerful alternative to the Stuart-Maxwell test.
Both tests are asymptotically equivalent and will produce comparable chi-squared
values when applied a large sample of rated objects.
References
Bhapkar, V.P. (1966). A note on the equivalence of two test criteria for hypotheses in
categorical data. Journal of the American Statistical Association, 61, 228-235.