Learn R Programming

irr (version 0.84.1)

maxwell: Maxwell's RE coefficient for binary data

Description

Computes Maxwell's RE as an index of the interrater agreement of binary data.

Usage

maxwell(ratings)

Value

A list with class '"irrlist"' containing the following components:

$method

a character string describing the method applied for the computation of interrater reliability.

$subjects

the number of subjects examined.

$raters

the number of raters (=2).

$irr.name

a character string specifying the name of the coefficient.

$value

value of RE.

Arguments

ratings

n*2 matrix or dataframe, n subjects 2 raters.

Author

Matthias Gamer

Details

Missing data are omitted in a listwise way.

References

Maxwell, A.E. (1977). Coefficients of agreement between observers and their interpretation. British Journal of Psychiatry, 130, 79-83.

See Also

kappa2

Examples

Run this code
data(anxiety)
# Median-split to generate binary data
r1 <- ifelse(anxiety$rater1

Run the code above in your browser using DataLab