powered by
Computes Robinson's A as an index of the interrater reliability of quantitative data.
robinson(ratings)
A list with class '"irrlist"' containing the following components:
a character string describing the method applied for the computation of interrater reliability.
the number of subjects examined.
the number of raters.
a character string specifying the name of the coefficient.
coefficient of interrater reliability.
n*m matrix or dataframe, n subjects m raters.
Matthias Gamer
Missing data are omitted in a listwise way.
Robinson, W.S. (1957). The statistical measurement of agreement. American Sociological Review, 22, 17-25.
finn, icc, meancor
finn
icc
meancor
data(anxiety) robinson(anxiety)
Run the code above in your browser using DataLab