powered by
Computes Maxwell's RE as an index of the interrater agreement of binary data.
maxwell(ratings)
A list with class '"irrlist"' containing the following components:
a character string describing the method applied for the computation of interrater reliability.
the number of subjects examined.
the number of raters (=2).
a character string specifying the name of the coefficient.
value of RE.
n*2 matrix or dataframe, n subjects 2 raters.
Matthias Gamer
Missing data are omitted in a listwise way.
Maxwell, A.E. (1977). Coefficients of agreement between observers and their interpretation. British Journal of Psychiatry, 130, 79-83.
kappa2
data(anxiety) # Median-split to generate binary data r1 <- ifelse(anxiety$rater1
Run the code above in your browser using DataLab